package com.ruoyi.web.controller.customer;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.customer.domain.qcc.FuzzySearch;
import com.ruoyi.customer.domain.qcc.QccFuzzySearchJsonResult;
import com.ruoyi.web.utils.IdUtils;
import com.ruoyi.web.utils.qcc.HttpHelper;
import com.ruoyi.web.utils.qcc.QiChaChaUtil;
import org.apache.http.client.methods.HttpHead;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.PropertySource;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.customer.domain.Customer;
import com.ruoyi.customer.service.ICustomerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 客户管理Controller
 *
 * @author ruoyi
 * @date 2024-03-25
 */
@RestController
@RequestMapping("/customer/customer")
@PropertySource("classpath:/common.yml")
public class CustomerController extends BaseController
{
    // 接口请求Key
    @Value("${qichacha.key}")
    private String Qcc_Key;
    @Value("${qichacha.secretKey}")
    private String Qcc_SecretKey;
    // 接口请求地址
    @Value("${qichacha.serviceName}")
    private String Qcc_serviceName;

    @Autowired
    private ICustomerService customerService;

    /**
     * 查询客户管理列表
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:list')")
    @GetMapping("/list")
    public TableDataInfo list(Customer customer)
    {
        startPage();
        List<Customer> list = customerService.selectCustomerList(customer);
        return getDataTable(list);
    }

    /**
     * 导出客户管理列表
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:export')")
    @Log(title = "客户信息导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Customer customer)
    {
        List<Customer> list = customerService.selectCustomerList(customer);
        ExcelUtil<Customer> util = new ExcelUtil<Customer>(Customer.class);
        util.exportExcel(response, list, "客户管理数据");
    }

    /**
     * 获取客户管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:query')")
    @GetMapping(value = "/{cusId}")
    public AjaxResult getInfo(@PathVariable("cusId") String cusId)
    {
        return success(customerService.selectCustomerByCusId(cusId));
    }

    /**
     * 新增客户管理
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:save')")
    @Log(title = "客户信息新增", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Customer customer)
    {
        customer.setCusId(UUID.fastUUID().toString());
        customer.setCusCode(IdUtils.createNo("KH_",2));
        customer.setCreateBy(getUsername());
        return toAjax(customerService.insertCustomer(customer));
    }

    /**
     * 修改客户管理
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:save')")
    @Log(title = "客户信息修改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Customer customer)
    {
        customer.setUpdateBy(getUsername());
        return toAjax(customerService.updateCustomer(customer));
    }

    /**
     * 提交客户信息
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:commit')")
    @Log(title = "客户信息提交", businessType = BusinessType.OTHER)
    @PostMapping("/commitCustomer")
    public AjaxResult commitCustomer(@RequestBody Customer customer)
    {
        String cus_id = customer.getCusId();
        if(StringUtils.isEmpty(cus_id)){
            customer.setCusId(UUID.fastUUID().toString());
            customer.setCusCode(IdUtils.createNo("KH_",2));
            customer.setCreateBy(getUsername());
            customerService.insertCustomer(customer);
            //提交OA中间表 TODO
            //....
            return success();
        }else{
            customer.setUpdateBy(getUsername());
            customerService.updateCustomer(customer);
            //提交OA中间表 TODO
            //....
            return success();
        }
    }

    /**
     * 删除客户管理
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:remove')")
    @Log(title = "客户信息删除", businessType = BusinessType.DELETE)
	@DeleteMapping("/{cusIds}")
    public AjaxResult remove(@PathVariable String[] cusIds)
    {
        return toAjax(customerService.deleteCustomerByCusIds(cusIds));
    }

    /***********************************************企查查模块************************************/
    /**
     * 查询企查查客户列表
     */
    @PreAuthorize("@ss.hasPermi('customer:customer:qcclist')")
    @Log(title = "企查查客户信息查询", businessType = BusinessType.OTHER)
    @GetMapping("/qccListCustomer")
    public TableDataInfo qccListCustomer(FuzzySearch qcc)
    {
        String customerName = qcc.getName();
        String reqInterNme = Qcc_serviceName;
        List<FuzzySearch> result = new ArrayList<FuzzySearch>();
        try {
            if(!StringUtils.isEmpty(customerName)){
                HttpHead reqHeader = new HttpHead();
                String[] autherHeader = QiChaChaUtil.RandomAuthentHeader(Qcc_Key, Qcc_SecretKey);
                reqHeader.setHeader("Token", autherHeader[0]);
                reqHeader.setHeader("Timespan", autherHeader[1]);
                String reqUri = reqInterNme.concat("?key=").concat(Qcc_Key).concat("&").concat("searchKey=").concat(customerName);
                String tokenJson = HttpHelper.httpGet(reqUri, reqHeader.getAllHeaders());
                System.out.println(String.format("==========================>this is response:{%s}", tokenJson));
                QccFuzzySearchJsonResult obj = JSON.parseObject(tokenJson, QccFuzzySearchJsonResult.class);
                result = obj.getResult();
            }
        } catch (Exception e1) {
            e1.printStackTrace();
        }
        return getDataTable(result);
    }
}
