package com.ruoyi.web.controller.quot;

import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.MinioUtil;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.quot.domain.QuotFile;
import com.ruoyi.quot.service.IQuotFileService;
import com.ruoyi.technicalConfirm.domain.QuotJsqr;
import com.ruoyi.technicalConfirm.service.IQuotJsqrService;
import com.ruoyi.web.utils.IdUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.quot.domain.Quot;
import com.ruoyi.quot.service.IQuotService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 报价Controller
 *
 * @author ruoyi
 * @date 2024-04-01
 */
@RestController
@RequestMapping("/quot/quot")
public class QuotController extends BaseController
{
    @Autowired
    private IQuotService quotService;

    @Autowired
    private IQuotFileService quotFileService;

    @Autowired
    private IQuotJsqrService quotJsqrService;


    /**
     * 查询报价列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:list')")
    @GetMapping("/list")
    public TableDataInfo list(Quot quot)
    {
        startPage();
        List<Quot> list = quotService.selectQuotList(quot);
        return getDataTable(list);
    }

    /**
     * 导出报价列表
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:export')")
    @Log(title = "报价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Quot quot)
    {
        List<Quot> list = quotService.selectQuotList(quot);
        ExcelUtil<Quot> util = new ExcelUtil<Quot>(Quot.class);
        util.exportExcel(response, list, "报价数据");
    }

    /**
     * 获取报价详细信息
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:query')")
    @GetMapping(value = "/{quotId}")
    public AjaxResult getInfo(@PathVariable("quotId") String quotId)
    {
        return success(quotService.selectQuotByQuotId(quotId));
    }

    /**
     * 新增报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:add')")
    @Log(title = "报价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Quot quot)
    {
        quot.setQuotId(UUID.fastUUID().toString());
        quot.setQuotCode(IdUtils.createNo("BJD_",2));
        quot.setCreateBy(getUsername());
        quot.setUpdateBy(getUsername());
        return toAjax(quotService.insertQuot(quot));
    }

    /**
     * 修改报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:edit')")
    @Log(title = "报价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Quot quot)
    {
        quot.setUpdateBy(getUsername());
        return toAjax(quotService.updateQuot(quot));
    }

    /**
     * 删除报价
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:remove')")
    @Log(title = "报价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{quotIds}")
    public AjaxResult remove(@PathVariable String[] quotIds)
    {
        return toAjax(quotService.deleteQuotByQuotIds(quotIds));
    }

    /**
     *
     * @param file 文件对象
     * @param relation_id 关联业务表Id
     * @param file_type 文件类别
     * @return
     * @throws Exception
     */
    @PreAuthorize("@ss.hasAnyPermi('quot:quot:list,jsqr:jsqr:list')")
    @Log(title = "上传报价附件", businessType = BusinessType.INSERT)
    @PostMapping("/quotFile")
    public AjaxResult quotFile(@RequestParam("quotFile") MultipartFile file,@RequestParam("relation_id") String relation_id,@RequestParam("file_type") String file_type) throws Exception
    {
        if(!StringUtils.isEmpty(relation_id)){
            if (!file.isEmpty())
            {
                QuotFile quotFile= new QuotFile();
                quotFile.setFileId(UUID.fastUUID().toString());

                String url = FileUploadUtils.uploadMinio(file,"quot-manage",  "quot/"+relation_id);
                int index = url.lastIndexOf("/")+1;
                String fileName = url.substring(index);//获取文件名

                int index2 = url.indexOf("/quot/");
                String fileBucketName = url.substring(index2);//获取文件对应文件服务器中地址-供后面删除功能用

                quotFile.setFileName(fileName);
                quotFile.setFileBucketName(fileBucketName);
                quotFile.setFileUrl(url);
                quotFile.setFileSize(file.getSize());
                quotFile.setFileTime(DateUtils.getTime());
                quotFile.setFileType(file_type);
                quotFile.setRelationId(relation_id);
                quotFileService.insertQuotFile(quotFile);
            }
        }else{
            return error("系统异常,报价单号为空!");
        }
        return success("上传成功!");
    }

    /**
     * 查询附件列表
     */
    @PreAuthorize("@ss.hasAnyPermi('quot:quot:list,jsqr:jsqr:list')")
    @GetMapping("/quotFileList")
    public TableDataInfo quotFileList(QuotFile quotFile)
    {
        startPage();
        List<QuotFile> list = quotFileService.selectQuotFileList(quotFile);
        return getDataTable(list);
    }

    /**
     * 删除附件列表
     */
    @PreAuthorize("@ss.hasAnyPermi('quot:quot:list,jsqr:jsqr:list')")
    @PostMapping("/quotFileDelete")
    public AjaxResult quotFileDelete(QuotFile quotFile) {
        String fileId = quotFile.getFileId();
        try {
            QuotFile quotfile = quotFileService.selectQuotFileByFileId(fileId);
            quotFileService.deleteQuotFileByFileId(fileId);//删除文件记录
            MinioUtil.removeObject("quot-manage", quotfile.getFileBucketName());//删除文件服务器对应文件
        }catch(Exception e){
            return error("系统异常!");
        }
        return success();
    }

    /**
     * 提交报价单至报价组
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:commit')")
    @Log(title = "报价单提交报价组", businessType = BusinessType.OTHER)
    @PostMapping("/commitQuot")
    public AjaxResult commitQuot(@RequestBody Quot quot)
    {
        String quot_id = quot.getQuotId();

        quot.setUpdateBy(getUsername());
        quot.setQuotApprovalStatus("1");//报价单 状态设置为 协助中
        quot.setQuotInquiryDate(DateUtils.getNowDate());//报价单 询价日期设置为 当前日期
        if(StringUtils.isEmpty(quot_id)){
            quot.setQuotId(UUID.fastUUID().toString());
            quot.setQuotCode(IdUtils.createNo("BJD_",2));
            quot.setCreateBy(getUsername());
            quotService.insertQuot(quot);
            return success();
        }else{
            quotService.updateQuot(quot);
            return success();
        }
    }

    /**
     * 报价单提交技术协助
     */
    @PreAuthorize("@ss.hasPermi('quot:quot:assist')")
    @Log(title = "报价单提交技术协助", businessType = BusinessType.OTHER)
    @PostMapping("/commitJsQuot")
    public AjaxResult commitJsQuot(@RequestBody Quot quot)
    {
        String quotJsxzGroup = "";
        String quotJsxzGroupArr[] = quot.getQuotJsxzGroup();
        if(quotJsxzGroupArr.length>0){
            quotJsxzGroup = StringUtils.join(quotJsxzGroupArr, ",");
            quot.setQuotJsxzGroupValues(quotJsxzGroup);
        }

        if(StringUtils.isEmpty(quotJsxzGroup)){
            return error("请先选择分组");
        }else{
            QuotJsqr quotJsqr = new QuotJsqr();
            String quotJsqrId = UUID.fastUUID().toString();
            quotJsqr.setQuotJsqrId(quotJsqrId);
            quotJsqr.setQuotJsqrCode(IdUtils.createNo("BJD_JSQR_",2));

            //特缆、低压、中压、其他 协助状态设置
            if(quotJsxzGroup.indexOf("TL")!=-1){
                quotJsqr.setQuotJsqrTlApprovalStatus("1");//特缆 协助状态 设置为 协助中
                quotJsqr.setQuotJsqrTlOperateState("0");//特缆 操作人状态 设置为 待通过
                quotJsqr.setQuotJsqrTlCheckState("0");//特缆 审核人状态 设置为 待通过
                quotJsqr.setQuotJsqrTlLeaderState("0");//特缆 组长状态 设置为 待通过
            }
            if(quotJsxzGroup.indexOf("DY")!=-1){
                quotJsqr.setQuotJsqrDyApprovalStatus("1");//低压 协助状态 设置为 协助中
                quotJsqr.setQuotJsqrDyOperateState("0");//低压 操作人状态 设置为 待通过
                quotJsqr.setQuotJsqrDyCheckState("0");//低压 审核人状态 设置为 待通过
                quotJsqr.setQuotJsqrDyLeaderState("0");//低压 组长状态 设置为 待通过
            }
            if(quotJsxzGroup.indexOf("ZY")!=-1){
                quotJsqr.setQuotJsqrZyApprovalStatus("1");//中压 协助状态 设置为 协助中
                quotJsqr.setQuotJsqrZyOperateState("0");//中压 操作人状态 设置为 待通过
                quotJsqr.setQuotJsqrZyCheckState("0");//中压 审核人状态 设置为 待通过
                quotJsqr.setQuotJsqrZyLeaderState("0");//中压 组长状态 设置为 待通过
            }
            if(quotJsxzGroup.indexOf("QT")!=-1){
                quotJsqr.setQuotJsqrQtApprovalStatus("1");//其他 协助状态 设置为 协助中
                quotJsqr.setQuotJsqrQtOperateState("0");//其他 操作人状态 设置为 待通过
                quotJsqr.setQuotJsqrQtCheckState("0");//其他 审核人状态 设置为 待通过
                quotJsqr.setQuotJsqrQtLeaderState("0");//其他 组长状态 设置为 待通过
            }

            quotJsqr.setCreateBy(getUsername());
            quotJsqr.setUpdateBy(getUsername());
            quotJsqrService.insertQuotJsqr(quotJsqr);//生成报价单-技术确认单

            quot.setQuotJsxzConfirmId(quotJsqrId);
            quot.setQuotJsxzApprovalStatus("1");//报价单-技术确认单 状态设置为 协助中
            quotService.updateQuot(quot);
        }
        return success();
    }
}
