package com.ruoyi.web.controller.sysSapUser;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.uuid.UUID;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sysSapUser.domain.SysSapUser;
import com.ruoyi.sysSapUser.service.ISysSapUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * SAP账户Controller
 *
 * @author ruoyi
 * @date 2024-04-02
 */
@RestController
@RequestMapping("/sysSapUser/sysSapUser")
public class SysSapUserController extends BaseController
{
    @Autowired
    private ISysSapUserService sysSapUserService;

    /**
     * 查询SAP账户列表
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysSapUser sysSapUser)
    {
        startPage();
        List<SysSapUser> list = sysSapUserService.selectSysSapUserList(sysSapUser);
        return getDataTable(list);
    }

    /**
     * 导出SAP账户列表
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:export')")
    @Log(title = "SAP账户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysSapUser sysSapUser)
    {
        List<SysSapUser> list = sysSapUserService.selectSysSapUserList(sysSapUser);
        ExcelUtil<SysSapUser> util = new ExcelUtil<SysSapUser>(SysSapUser.class);
        util.exportExcel(response, list, "SAP账户数据");
    }

    /**
     * 获取SAP账户详细信息
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:query')")
    @GetMapping(value = "/{sapUserId}")
    public AjaxResult getInfo(@PathVariable("sapUserId") String sapUserId)
    {
        return success(sysSapUserService.selectSysSapUserBySapUserId(sapUserId));
    }

    /**
     * 新增SAP账户
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:add')")
    @Log(title = "SAP账户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysSapUser sysSapUser)
    {
        sysSapUser.setSapUserId(UUID.fastUUID().toString());
        return toAjax(sysSapUserService.insertSysSapUser(sysSapUser));
    }

    /**
     * 修改SAP账户
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:edit')")
    @Log(title = "SAP账户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysSapUser sysSapUser)
    {
        return toAjax(sysSapUserService.updateSysSapUser(sysSapUser));
    }

    /**
     * 删除SAP账户
     */
    @PreAuthorize("@ss.hasPermi('sysSapUser:sysSapUser:remove')")
    @Log(title = "SAP账户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{sapUserIds}")
    public AjaxResult remove(@PathVariable String[] sapUserIds)
    {
        return toAjax(sysSapUserService.deleteSysSapUserBySapUserIds(sapUserIds));
    }
}
