package com.ruoyi.web.controller.technicalConfirm;

import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.quot.domain.Quot;
import com.ruoyi.quot.service.IQuotService;
import com.ruoyi.technicalConfirm.domain.QuotJsqr;
import com.ruoyi.technicalConfirm.domain.QuotJsqrXzDetail;
import com.ruoyi.technicalConfirm.service.IQuotJsqrService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

import java.util.List;

/**
 * 报价单-技术确认单Controller
 *
 * @author ruoyi
 * @date 2024-04-07
 */
@RestController
@RequestMapping("/jsqr/jsqr")
public class QuotJsqrController extends BaseController
{
    @Autowired
    private IQuotJsqrService quotJsqrService;

    @Autowired
    private IQuotService quotService;

    /**
     * 查询报价单-技术确认单列表
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:list')")
    @GetMapping("/list")
    public TableDataInfo list(QuotJsqr quotJsqr)
    {
        startPage();
        List<QuotJsqr> list = quotJsqrService.selectQuotJsqrList(quotJsqr);
        return getDataTable(list);
    }

    /**
     * 导出报价单-技术确认单列表
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:export')")
    @Log(title = "报价单-技术确认单导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QuotJsqr quotJsqr)
    {
        List<QuotJsqr> list = quotJsqrService.selectQuotJsqrList(quotJsqr);
        ExcelUtil<QuotJsqr> util = new ExcelUtil<QuotJsqr>(QuotJsqr.class);
        util.exportExcel(response, list, "报价单-技术确认单数据");
    }

    /**
     * 获取报价单-技术确认单详细信息
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:query')")
    @GetMapping(value = "/{quotJsqrId}")
    public AjaxResult getInfo(@PathVariable("quotJsqrId") String quotJsqrId)
    {
        return success(quotJsqrService.selectQuotJsqrByQuotJsqrId(quotJsqrId));
    }

    /**
     * 修改报价单-技术确认单
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:edit')")
    @Log(title = "报价单-技术确认单查看", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QuotJsqr quotJsqr)
    {
        return toAjax(quotJsqrService.updateQuotJsqr(quotJsqr));
    }

    /**
     * 删除报价单-技术确认单
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:remove')")
    @Log(title = "报价单-技术确认单删除", businessType = BusinessType.DELETE)
	@DeleteMapping("/{quotJsqrIds}")
    public AjaxResult remove(@PathVariable String[] quotJsqrIds)
    {
        return toAjax(quotJsqrService.deleteQuotJsqrByQuotJsqrIds(quotJsqrIds));
    }

    /**
     * 操作人确认事件
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:query')")
    @Log(title = "报价单-技术确认单协助操作", businessType = BusinessType.UPDATE)
    @PostMapping("/doOperate")
    public AjaxResult doOperate(HttpServletResponse response, @RequestBody QuotJsqrXzDetail info)
    {
        QuotJsqr quotJsqr = new QuotJsqr();
        String quotJsqrId = info.getQuotJsqrId();
        quotJsqr.setQuotJsqrId(quotJsqrId);

        String quotJsxzGroup = info.getQuotJsxzGroup();//组名
        String type = info.getType();//操作人、审核人、组长
        String state = info.getState();//通过/驳回
        String fileNum = info.getFileNum();//操作人反馈附件数

        if("TL".equals(quotJsxzGroup)){//特缆组 操作人、审核人、组长 对应按钮事件
            if("operater".equals(type)){//操作人通过、驳回
                quotJsqr.setQuotJsqrTlOperateUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrTlOperateTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrTlOperateState(state);

                String quotJsqrTlRemark = info.getQuotJsqrTlRemark();
                if("3".equals(state)){//驳回
                    if(StringUtils.isEmpty(quotJsqrTlRemark)){
                        return error("特缆协助说明不能为空");
                    }
                    quotJsqr.setQuotJsqrTlApprovalStatus("3");//特缆协助状态 设置为 驳回
                }else if("2".equals(state)){
                    if("0".equals(fileNum)&&"".equals(quotJsqrTlRemark)){
                        return error("特缆反馈附件 或 特缆协助说明 至少填写一项");
                    }
                }
            }
            if("checker".equals(type)){//审核人通过、驳回
                quotJsqr.setQuotJsqrTlCheckUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrTlCheckTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrTlCheckState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrTlCheckRemark = info.getQuotJsqrTlCheckRemark();
                    if(StringUtils.isEmpty(quotJsqrTlCheckRemark)){
                        return error("特缆审核意见不能为空");
                    }
                    quotJsqr.setQuotJsqrTlOperateState("0");//特缆操作状态 设置为 待通过
                }
            }
            if("leader".equals(type)){//组长通过、驳回
                quotJsqr.setQuotJsqrTlLeaderUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrTlLeaderTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrTlLeaderState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrTlLeaderRemark = info.getQuotJsqrTlLeaderRemark();
                    if(StringUtils.isEmpty(quotJsqrTlLeaderRemark)){
                        return error("特缆组长确认意见不能为空");
                    }
                    quotJsqr.setQuotJsqrTlOperateState("0");//特缆操作状态 设置为 待通过
                    quotJsqr.setQuotJsqrTlCheckState("0");//特缆审核状态 设置为 待通过
                }else{
                    quotJsqr.setQuotJsqrTlApprovalStatus("2");//特缆协助状态 设置为 已协助
                }
            }
        }else if("DY".equals(quotJsxzGroup)){//低压组 操作人、审核人、组长 对应按钮事件
            if("operater".equals(type)){//操作人通过、驳回
                quotJsqr.setQuotJsqrDyOperateUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrDyOperateTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrDyOperateState(state);

                String quotJsqrDyRemark = info.getQuotJsqrDyRemark();
                if("3".equals(state)){//驳回
                    if(StringUtils.isEmpty(quotJsqrDyRemark)){
                        return error("低压协助说明不能为空");
                    }
                    quotJsqr.setQuotJsqrDyApprovalStatus("3");//低压协助状态 设置为 驳回
                }else if("2".equals(state)){
                    if("0".equals(fileNum)&&"".equals(quotJsqrDyRemark)){
                        return error("低压反馈附件 或 低压协助说明 至少填写一项");
                    }
                }
            }
            if("checker".equals(type)){//审核人通过、驳回
                quotJsqr.setQuotJsqrDyCheckUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrDyCheckTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrDyCheckState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrDyCheckRemark = info.getQuotJsqrDyCheckRemark();
                    if(StringUtils.isEmpty(quotJsqrDyCheckRemark)){
                        return error("低压审核意见不能为空");
                    }
                    quotJsqr.setQuotJsqrDyOperateState("0");//低压操作状态 设置为 待通过
                }
            }
            if("leader".equals(type)){//组长通过、驳回
                quotJsqr.setQuotJsqrDyLeaderUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrDyLeaderTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrDyLeaderState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrDyLeaderRemark = info.getQuotJsqrDyLeaderRemark();
                    if(StringUtils.isEmpty(quotJsqrDyLeaderRemark)){
                        return error("低压组长确认意见不能为空");
                    }
                    quotJsqr.setQuotJsqrDyOperateState("0");//低压操作状态 设置为 待通过
                    quotJsqr.setQuotJsqrDyCheckState("0");//低压审核状态 设置为 待通过
                }else{
                    quotJsqr.setQuotJsqrDyApprovalStatus("2");//低压协助状态 设置为 已协助
                }
            }
        }else if("ZY".equals(quotJsxzGroup)){//中压组 操作人、审核人、组长 对应按钮事件
            if("operater".equals(type)){//操作人通过、驳回
                quotJsqr.setQuotJsqrZyOperateUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrZyOperateTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrZyOperateState(state);

                String quotJsqrZyRemark = info.getQuotJsqrZyRemark();
                if("3".equals(state)){//驳回
                    if(StringUtils.isEmpty(quotJsqrZyRemark)){
                        return error("中压协助说明不能为空");
                    }
                    quotJsqr.setQuotJsqrZyApprovalStatus("3");//中压协助状态 设置为 驳回
                }else if("2".equals(state)){
                    if("0".equals(fileNum)&&"".equals(quotJsqrZyRemark)){
                        return error("中压反馈附件 或 低压协助说明 至少填写一项");
                    }
                }
            }
            if("checker".equals(type)){//审核人通过、驳回
                quotJsqr.setQuotJsqrZyCheckUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrZyCheckTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrZyCheckState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrZyCheckRemark = info.getQuotJsqrZyCheckRemark();
                    if(StringUtils.isEmpty(quotJsqrZyCheckRemark)){
                        return error("中压审核意见不能为空");
                    }
                    quotJsqr.setQuotJsqrZyOperateState("0");//中压操作状态 设置为 待通过
                }
            }
            if("leader".equals(type)){//组长通过、驳回
                quotJsqr.setQuotJsqrZyLeaderUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrZyLeaderTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrZyLeaderState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrZyLeaderRemark = info.getQuotJsqrZyLeaderRemark();
                    if(StringUtils.isEmpty(quotJsqrZyLeaderRemark)){
                        return error("中压组长确认意见不能为空");
                    }
                    quotJsqr.setQuotJsqrZyOperateState("0");//中压操作状态 设置为 待通过
                    quotJsqr.setQuotJsqrZyCheckState("0");//中压审核状态 设置为 待通过
                }else{
                    quotJsqr.setQuotJsqrZyApprovalStatus("2");//中压协助状态 设置为 已协助
                }
            }
        }else if("QT".equals(quotJsxzGroup)){//其他组 操作人、审核人、组长 对应按钮事件
            if("operater".equals(type)){//操作人通过、驳回
                quotJsqr.setQuotJsqrQtOperateUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrQtOperateTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrQtOperateState(state);

                String quotJsqrQtRemark = info.getQuotJsqrQtRemark();
                if("3".equals(state)){//驳回
                    if(StringUtils.isEmpty(quotJsqrQtRemark)){
                        return error("其他协助说明不能为空");
                    }
                    quotJsqr.setQuotJsqrQtApprovalStatus("3");//其他协助状态 设置为 驳回
                }else if("2".equals(state)){
                    if("0".equals(fileNum)&&"".equals(quotJsqrQtRemark)){
                        return error("其他反馈附件 或 其他协助说明 至少填写一项");
                    }
                }
            }
            if("checker".equals(type)){//审核人通过、驳回
                quotJsqr.setQuotJsqrQtCheckUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrQtCheckTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrQtCheckState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrQtCheckRemark = info.getQuotJsqrQtCheckRemark();
                    if(StringUtils.isEmpty(quotJsqrQtCheckRemark)){
                        return error("其他审核意见不能为空");
                    }
                    quotJsqr.setQuotJsqrQtOperateState("0");//其他操作状态 设置为 待通过
                }
            }
            if("leader".equals(type)){//组长通过、驳回
                quotJsqr.setQuotJsqrQtLeaderUserName(getLoginUser().getUser().getNickName());
                quotJsqr.setQuotJsqrQtLeaderTime(DateUtils.getTime());
                quotJsqr.setQuotJsqrQtLeaderState(state);
                if("3".equals(state)){//驳回
                    String quotJsqrQtLeaderRemark = info.getQuotJsqrQtLeaderRemark();
                    if(StringUtils.isEmpty(quotJsqrQtLeaderRemark)){
                        return error("其他确认意见不能为空");
                    }
                    quotJsqr.setQuotJsqrQtOperateState("0");//其他操作状态 设置为 待通过
                    quotJsqr.setQuotJsqrQtCheckState("0");//其他审核状态 设置为 待通过
                }else{
                    quotJsqr.setQuotJsqrQtApprovalStatus("2");//其他协助状态 设置为 已协助
                }
            }
        }
        quotJsqrService.updateQuotJsqr(quotJsqr);
        return success(quotJsqr);
    }

    /**
     * 报价单-技术确认单 提交报价组
     */
    @PreAuthorize("@ss.hasPermi('jsqr:jsqr:commit')")
    @Log(title = "报价单-技术确认单 提交报价组", businessType = BusinessType.UPDATE)
    @PostMapping("/commitQuot")
    public AjaxResult commitQuot(@RequestBody QuotJsqr quotJsqr)
    {
        String quotJsqrId = quotJsqr.getQuotJsqrId();

        QuotJsqr info = quotJsqrService.selectQuotJsqrByQuotJsqrId(quotJsqrId);
        Quot quot = quotService.selectQuotByQuotJsqrId(quotJsqrId);

        String quot_jsxz_group = quot.getQuotJsxzGroupValues();//技术协助单-分组
        String quotJsxzConfirmId = quot.getQuotJsxzConfirmId();//技术协助单Id

        if(StringUtils.isNotEmpty(quotJsxzConfirmId)){
            Boolean tlFlag = true;
            if(quot_jsxz_group.indexOf("TL")!=-1) {//校验特缆 操作人、审核人、组长 通过情况
                String quot_jsqr_tl_approval_status = info.getQuotJsqrTlApprovalStatus();
                if ("1".equals(quot_jsqr_tl_approval_status)) {
                    tlFlag = false;
                }
            }
            if(!tlFlag){
                return error("特缆协助还未完成");
            }

            Boolean dyFlag = true;
            if(quot_jsxz_group.indexOf("DY")!=-1) {//校验特缆 操作人、审核人、组长 通过情况
                String quot_jsqr_dy_approval_status = info.getQuotJsqrDyApprovalStatus();
                if ("1".equals(quot_jsqr_dy_approval_status)) {
                    dyFlag = false;
                }
            }
            if(!dyFlag){
                return error("低压协助还未完成");
            }

            Boolean zyFlag = true;
            if(quot_jsxz_group.indexOf("ZY")!=-1) {//校验特缆 操作人、审核人、组长 通过情况
                String quot_jsqr_zy_approval_status = info.getQuotJsqrZyApprovalStatus();
                if ("1".equals(quot_jsqr_zy_approval_status)) {
                    zyFlag = false;
                }
            }
            if(!zyFlag){
                return error("中压协助还未完成");
            }

            Boolean qtFlag = true;
            if(quot_jsxz_group.indexOf("QT")!=-1) {//校验特缆 操作人、审核人、组长 通过情况
                String quot_jsqr_qt_approval_status = info.getQuotJsqrQtApprovalStatus();
                if ("1".equals(quot_jsqr_qt_approval_status)) {
                    qtFlag = false;
                }
            }
            if(!qtFlag){
                return error("其他(防火、轨道、架空)协助还未完成");
            }
            quot.setQuotJsxzApprovalStatus("2");//报价单-技术协助状态 设置为 已协助
        }
        return success(quotService.updateQuot(quot));
    }
}
