package com.ruoyi.quartz.service.impl;
import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.quartz.domain.c_rb_product_price;
import com.ruoyi.quartz.domain.c_rb_productbase_price;
import com.ruoyi.quartz.mapper.SapTjMapper;
import com.ruoyi.quartz.service.SapTjService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;


/**
 * core job action for xxl-job
 * @author xuxueli 2016-5-28 15:30:33
 */
@Service
public class SapTjServiceImpl implements SapTjService {

	@Resource
	private SapTjMapper sapTjMapper;

	/**
	 * 获取红本调价版本
	 * @return
	 */
	@DataSource(DataSourceType.REDBOOK)
	@Override
	public String selRbVersionUid() {
		return sapTjMapper.selRbVersionUid();
	}

	/**
	 * 获取本地红本调价版本
	 * @return
	 */
	@DataSource(DataSourceType.QUOT)
	@Override
	public String selLocVersionUid() {return sapTjMapper.selLocVersionUid(); }


	/**
	 * 获取红本价格
	 * @param rbVersionUid
	 * @return
	 */
	@DataSource(DataSourceType.REDBOOK)
	@Override
	public List<c_rb_product_price> getProductPriceList(String rbVersionUid) {return sapTjMapper.getProductPriceList(rbVersionUid); }

	/**
	 * 获取红本成本价格
	 * @param rbVersionUid
	 * @return
	 */
	@DataSource(DataSourceType.REDBOOK)
	@Override
	public List<c_rb_productbase_price> getProductBasePriceList(String rbVersionUid) {return sapTjMapper.getProductBasePriceList(rbVersionUid); }

	/**
	 * 删除本地红本价格表
	 */
	@DataSource(DataSourceType.QUOT)
	@Override
	public void deleteLocProductPrice() {sapTjMapper.deleteLocProductPrice(); }

	/**
	 * 删除本地红本成本价格表
	 */
	@DataSource(DataSourceType.QUOT)
	@Override
	public void deleteLocProductBasePrice() {sapTjMapper.deleteLocProductBasePrice(); }

	/**
	 * RbProductPrice表是否有更新
	 * @param rbVersionUid
	 * @return
	 */
	@DataSource(DataSourceType.REDBOOK)
	@Override
	public String selRbProductPriceVersionUid(String rbVersionUid) {
		return sapTjMapper.selRbProductPriceVersionUid(rbVersionUid);
	}

	/**
	 * RbProductBasePrice表是否有更新
	 * @param rbVersionUid
	 * @return
	 */
	@DataSource(DataSourceType.REDBOOK)
	@Override
	public String selRbProductBasePriceVersionUid(String rbVersionUid) {
		return sapTjMapper.selRbProductBasePriceVersionUid(rbVersionUid);
	}

	/**
	 * 更新本地c_rb_version表
	 * @param rbVersionUid
	 */
	@DataSource(DataSourceType.QUOT)
	@Override
	public void updateLocRbVersion(String rbVersionUid) {
		sapTjMapper.updateLocRbVersion(rbVersionUid);
	}


}
