package com.ruoyi.customer.service.impl;

import java.util.List;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.uuid.UUID;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.customer.domain.Bank;
import com.ruoyi.customer.mapper.CustomerMapper;
import com.ruoyi.customer.domain.Customer;
import com.ruoyi.customer.service.ICustomerService;

/**
 * 客户管理Service业务层处理
 *
 * @author ruoyi
 * @date 2024-03-25
 */
@Service
public class CustomerServiceImpl implements ICustomerService
{
    @Autowired
    private CustomerMapper customerMapper;

    /**
     * 查询客户管理
     *
     * @param cusId 客户管理主键
     * @return 客户管理
     */
    @Override
    public Customer selectCustomerByCusId(String cusId)
    {
        return customerMapper.selectCustomerByCusId(cusId);
    }

    /**
     * 查询客户管理列表
     *
     * @param customer 客户管理
     * @return 客户管理
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Customer> selectCustomerList(Customer customer)
    {
        return customerMapper.selectCustomerList(customer);
    }

    /**
     * 新增客户管理
     *
     * @param customer 客户管理
     * @return 结果
     */
    @Transactional
    @Override
    public int insertCustomer(Customer customer)
    {
        int rows = customerMapper.insertCustomer(customer);
        insertBank(customer);
        return rows;
    }

    /**
     * 修改客户管理
     *
     * @param customer 客户管理
     * @return 结果
     */
    @Transactional
    @Override
    public int updateCustomer(Customer customer)
    {
        customerMapper.deleteBankByCusId(customer.getCusId());
        insertBank(customer);
        return customerMapper.updateCustomer(customer);
    }

    /**
     * 批量删除客户管理
     *
     * @param cusIds 需要删除的客户管理主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCustomerByCusIds(String[] cusIds)
    {
        customerMapper.deleteBankByCusIds(cusIds);
        return customerMapper.deleteCustomerByCusIds(cusIds);
    }

    /**
     * 删除客户管理信息
     *
     * @param cusId 客户管理主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteCustomerByCusId(String cusId)
    {
        customerMapper.deleteBankByCusId(cusId);
        return customerMapper.deleteCustomerByCusId(cusId);
    }

    /**
     * 新增银行信息
     *
     * @param customer 客户管理对象
     */
    public void insertBank(Customer customer)
    {
        List<Bank> bankList = customer.getBankList();
        String cusId = customer.getCusId();
        if (StringUtils.isNotNull(bankList))
        {
            List<Bank> list = new ArrayList<Bank>();
            for (Bank bank : bankList)
            {
                bank.setBankId(UUID.fastUUID().toString());
                bank.setCusId(cusId);
                list.add(bank);
            }
            if (list.size() > 0)
            {
                customerMapper.batchBank(list);
            }
        }
    }
}
