package com.ruoyi.quot.service.impl;

import java.util.List;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.UUID;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.quot.domain.QuotMaterial;
import com.ruoyi.quot.mapper.QuotMapper;
import com.ruoyi.quot.domain.Quot;
import com.ruoyi.quot.service.IQuotService;

/**
 * 报价Service业务层处理
 *
 * @author ruoyi
 * @date 2024-04-01
 */
@Service
public class QuotServiceImpl implements IQuotService
{
    @Autowired
    private QuotMapper quotMapper;

    /**
     * 查询报价
     *
     * @param quotId 报价主键
     * @return 报价
     */
    @Override
    public Quot selectQuotByQuotId(String quotId)
    {
        return quotMapper.selectQuotByQuotId(quotId);
    }

    /**
     * 查询报价列表
     *
     * @param quot 报价
     * @return 报价
     */
    @Override
    @DataScope(deptAlias = "d", userAlias = "u")
    public List<Quot> selectQuotList(Quot quot)
    {
        return quotMapper.selectQuotList(quot);
    }

    /**
     * 新增报价
     *
     * @param quot 报价
     * @return 结果
     */
    @Transactional
    @Override
    public int insertQuot(Quot quot)
    {
        quot.setCreateTime(DateUtils.getNowDate());
        quot.setUpdateTime(DateUtils.getNowDate());
        int rows = quotMapper.insertQuot(quot);
        insertQuotMaterial(quot);
        return rows;
    }

    /**
     * 修改报价
     *
     * @param quot 报价
     * @return 结果
     */
    @Transactional
    @Override
    public int updateQuot(Quot quot)
    {
        quot.setUpdateTime(DateUtils.getNowDate());
        quotMapper.deleteQuotMaterialByQuotId(quot.getQuotId());
        insertQuotMaterial(quot);
        return quotMapper.updateQuot(quot);
    }

    /**
     * 批量删除报价
     *
     * @param quotIds 需要删除的报价主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteQuotByQuotIds(String[] quotIds)
    {
        quotMapper.deleteQuotMaterialByQuotIds(quotIds);
        return quotMapper.deleteQuotByQuotIds(quotIds);
    }

    /**
     * 删除报价信息
     *
     * @param quotId 报价主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteQuotByQuotId(String quotId)
    {
        quotMapper.deleteQuotMaterialByQuotId(quotId);
        return quotMapper.deleteQuotByQuotId(quotId);
    }

    /**
     * 技术确认单Id
     * @param quotJsqrId
     * @return
     */
    @Override
    public Quot selectQuotByQuotJsqrId(String quotJsqrId) {
        return quotMapper.selectQuotByQuotJsqrId(quotJsqrId);
    }

    /**
     * 新增报价单-产品信息
     *
     * @param quot 报价对象
     */
    public void insertQuotMaterial(Quot quot)
    {
        List<QuotMaterial> quotMaterialList = quot.getQuotMaterialList();
        String quotId = quot.getQuotId();
        if (StringUtils.isNotNull(quotMaterialList))
        {
            List<QuotMaterial> list = new ArrayList<QuotMaterial>();
            for (QuotMaterial quotMaterial : quotMaterialList)
            {
                quotMaterial.setMatId(UUID.fastUUID().toString());
                quotMaterial.setQuotId(quotId);
                list.add(quotMaterial);
            }
            if (list.size() > 0)
            {
                quotMapper.batchQuotMaterial(list);
            }
        }
    }
}
